@@ -1,18 +1,17 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
 use utf8;
 
 package Dist::Zilla::UtilRole::MaybeGit;
-BEGIN {
-  $Dist::Zilla::UtilRole::MaybeGit::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Dist::Zilla::UtilRole::MaybeGit::VERSION = '0.003000';
-}
+
+our $VERSION = '0.004000';
 
 # ABSTRACT: A role to make adding a ->git method easy, and low-complexity
 
-use Moose::Role;
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Moose::Role qw( with has );
 with 'Dist::Zilla::UtilRole::MaybeZilla';
 
 has 'git' => ( is => ro =>, isa => Object =>, lazy_build => 1 );
@@ -38,7 +37,7 @@ Dist::Zilla::UtilRole::MaybeGit - A role to make adding a ->git method easy, and
 
 =head1 VERSION
 
-version 0.003000
+version 0.004000
 
 =head1 AUTHOR
 
@@ -46,7 +45,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
